
.. only:: html

    :Release: |version|
    :Date: |today|

   .. Download `PDF <./Quantities.pdf>`_

.. _contents:

Quantities
==========

Quantities is designed to handle arithmetic and conversions of physical
quantities, which have a magnitude, dimensionality specified by various units,
and possibly an uncertainty. Quantities builds on the popular numpy library
and is designed to work with numpy's standard ufuncs, many of which are
already supported.

Quantities is actively developed, and while the current features and API are
stable, test coverage is incomplete and the package is not ready for
production use. Python-2.6.0 or later is required.

.. toctree::
   :maxdepth: 2

   user/index.rst
   devel/index.rst
